@@ -35,7 +35,8 @@ class LDPModelManager(models.Manager):
         # include all many-to-many relations
         for field_name, relation_info in model_meta.get_field_info(self.model).relations.items():
             if relation_info.to_many:
-                nested_fields.add(field_name)
+                if field_name is not None:
+                    nested_fields.add(field_name)
         # include all nested fields explicitly included on the model
         nested_fields.update(set(Model.get_meta(self.model, 'nested_fields', set())))
         # exclude anything marked explicitly to be excluded
@@ -300,9 +301,7 @@ class Activity(Model):
         rdf_type = 'as:Activity'
 
     def to_activitystream(self):
-        payload = self.payload.decode("utf-8")
-        data = json.loads(payload)
-        return data
+        return json.loads(self.payload.tobytes())
 
 
 class Follower(Model):
